@@ -9,6 +9,7 @@ our @EXPORT = qw(
     skip_suite_unless_run_all
     ok_sets_cmp
     ok_dies
+    tolerate_delay
 );
 
 use Time::HiRes 'time';
@@ -60,4 +61,23 @@ sub skip_suite_unless_run_all {
     }
 }
 
+# This subroutine allows you to run a coderef until it returns true,
+# waiting one second between calls. If a threshold of one minute is
+# reached, we print a skip message and move on.
+#
+# Useful for testing searching after tagging for example, since new
+# tags are not visible immediately for searching.
+sub tolerate_delay(&) {
+    my $code = shift;
+
+    SKIP: {
+        for (my $n = 0; $n < 60; ++$n) {
+            return if $code->();
+            sleep 1;
+        }
+
+        skip "search is taking too long, skipping", 1;
+    }
+}
+
 1;
\ No newline at end of file
